@@ -33,17 +33,15 @@
 
 #include "flowlayout.h"
 #include "termlabel.h"
-//#include "project.h"
 
-// #include <klocale.h>
-#include <kdebug.h>
-#include <kaction.h>
+#include <QAction>
+#include <QDebug>
 
 using namespace GlossaryNS;
 
 FlowLayout::FlowLayout(User user,
                        QWidget *signalingWidget,
-                       const QVector<KAction*>& actions,
+                       const QVector<QAction*>& actions,
                        int margin,
                        int spacing)
         : QLayout()
@@ -56,7 +54,7 @@ FlowLayout::FlowLayout(User user,
 
     if (user==glossary)
     {
-        foreach (KAction* action, actions)
+        foreach (QAction* action, actions)
         {
             TermLabel* label=new TermLabel(action); /*this,m_keys.at(count())*/
             connect(action,SIGNAL(triggered(bool)),label,SLOT(insert()));
