@@ -136,8 +136,8 @@ QVariant PhasesModel::data(const QModelIndex& index, int role) const
         case Process:    return phase.process;
         case Company:    return phase.company;
         case Contact:    return QString(phase.contact
-                           %(phase.email.isEmpty()?QString():QString(QStringLiteral(" <%1> ")).arg(phase.email))
-                           %(phase.phone.isEmpty()?QString():QString(QStringLiteral(", %1")).arg(phase.phone)));
+                           %(phase.email.isEmpty()?QString():QStringLiteral(" <%1> ").arg(phase.email))
+                           %(phase.phone.isEmpty()?QString():QStringLiteral(", %1").arg(phase.phone)));
         case ToolName:       return m_tools.value(phase.tool).name;
     }
     return QVariant();
@@ -307,7 +307,7 @@ void PhasesWindow::anchorClicked(QUrl link)
 {
     QString path=link.path().mid(1);// minus '/'
 
-    if (link.scheme()=="note")
+    if (link.scheme()==QLatin1String("note"))
     {
         if (!m_editor)
         {
@@ -317,7 +317,7 @@ void PhasesWindow::anchorClicked(QUrl link)
             connect(m_editor,SIGNAL(rejected()),this,SLOT(noteEditRejected()));
         }
         m_editor->setNoteAuthors(m_catalog->noteAuthors());
-        if (path.endsWith("add"))
+        if (path.endsWith(QLatin1String("add")))
             m_editor->setNote(Note(),-1);
         else
         {
